@@ -34,8 +34,8 @@
 #include <goffice/graph/gog-plot.h>
 #include <goffice/graph/gog-plot-impl.h>
 #include <goffice/graph/gog-renderer.h>
+#include <goffice/math/go-math.h>
 #include <goffice/utils/go-format.h>
-#include <goffice/utils/go-math.h>
 #include <goffice/data/go-data-simple.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -292,9 +292,11 @@ map_discrete_calc_ticks (GogAxis *axis)
 		index = ticks[j].position - 1;
 		ticks[j].type = GOG_AXIS_TICK_NONE;
 		if (axis->labels != NULL) {
-			if (index < go_data_vector_get_len (axis->labels) && index >= 0)
-				ticks[j].label = go_data_vector_get_str (axis->labels, index);
-			else
+			if (index < go_data_vector_get_len (axis->labels) && index >= 0) {
+				char *label = go_data_vector_get_str (axis->labels, index);
+				ticks[j].label = g_markup_escape_text (label, -1);
+				g_free (label);
+			} else
 				ticks[j].label = NULL;
 		}
 		else
@@ -781,9 +783,8 @@ gog_axis_map_set (GogAxis *axis, char const *name)
  * Tests if @map was correctly initialized, i.e. if bounds are
  * valid.
  * 
- * returns: %TRUE if map is valid
+ * Returns: %TRUE if map is valid
  **/
-
 gboolean
 gog_axis_map_is_valid (GogAxisMap *map) 
 {
@@ -803,9 +804,8 @@ gog_axis_map_is_valid (GogAxisMap *map)
  * gog_axis_map_to_view in order to translates data coordinates 
  * into canvas space.
  *
- * returns: a newly allocated #GogAxisMap.
+ * Returns: a newly allocated #GogAxisMap.
  **/
-
 GogAxisMap *
 gog_axis_map_new (GogAxis *axis, double offset, double length)
 {
@@ -835,9 +835,8 @@ gog_axis_map_new (GogAxis *axis, double offset, double length)
  * Converts @value to plot coordinates. A value in [0,1.0] range means a data 
  * within axis bounds.
  *
- * returns: mapped value.
+ * Returns: mapped value.
  **/
-
 double 
 gog_axis_map (GogAxisMap *map,
 	      double value)
@@ -892,7 +891,7 @@ gog_axis_map_to_view (GogAxisMap *map,
  * return value: %TRUE if value means something
  **/
 
-gboolean 
+gboolean
 gog_axis_map_finite (GogAxisMap *map, double value)
 {
 	return map->desc->map_finite (value);
@@ -931,9 +930,9 @@ void
 gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
 {
 	if (map->axis->inverted)
-		return map->desc->map_bounds (map, stop, start);
+		map->desc->map_bounds (map, stop, start);
 	else
-		return map->desc->map_bounds (map, start, stop);
+		map->desc->map_bounds (map, start, stop);
 }
 
 /**
@@ -952,8 +951,25 @@ gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
 void
 gog_axis_map_get_bounds (GogAxisMap *map, double *minimum, double *maximum)
 {
-	return map->desc->map_bounds (map, minimum, maximum);
+	map->desc->map_bounds (map, minimum, maximum);
 }
+
+/**
+ * gog_axis_map_is_inverted:
+ * @map: a #GogAxisMap
+ *
+ * Accessor to the axis is_inverted property.
+ **/
+
+gboolean
+gog_axis_map_is_inverted (GogAxisMap *map)
+{
+	g_return_val_if_fail (map != NULL, FALSE);
+	g_return_val_if_fail (IS_GOG_AXIS (map->axis), FALSE);
+
+	return map->axis->inverted;
+}
+
 /**
  * gog_axis_map_free :
  * @map : a #GogAxisMap
@@ -980,7 +996,7 @@ gog_axis_auto_bound (GogAxis *axis)
 	double maximum, minimum;
 	double tmp;
 	gboolean user_defined;
-	
+
 	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	minimum = axis->min_val;
@@ -1127,7 +1143,8 @@ role_label_can_add (GogObject const *parent)
  * @fmt  : #GOFormat
  *
  * Absorbs a reference to @fmt, and accepts NULL.
- * returns TRUE if things changed
+ *
+ * Returns: TRUE if things changed
  **/
 gboolean
 gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
@@ -1150,7 +1167,7 @@ gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
  * gog_axis_get_format :
  * @axis :#GogAxis
  *
- * Returns the format assigned to @axis but does not add a reference.
+ * Returns: the format assigned to @axis but does not add a reference.
  **/
 GOFormat *
 gog_axis_get_format (GogAxis const *axis)
@@ -1196,7 +1213,7 @@ gog_axis_set_property (GObject *obj, guint param_id,
 	case AXIS_PROP_ASSIGNED_FORMAT_STR_XL : {
 		char const *str = g_value_get_string (value);
 		resized = gog_axis_set_format (axis, (str != NULL)
-			? go_format_new_from_XL (str, FALSE)
+			? go_format_new_from_XL (str)
 			: NULL);
 		calc_ticks = resized;
 		break;
@@ -1250,8 +1267,8 @@ gog_axis_get_property (GObject *obj, guint param_id,
 		break;
 	case AXIS_PROP_ASSIGNED_FORMAT_STR_XL :
 		if (axis->assigned_format != NULL)
-			g_value_take_string (value,
-				go_format_as_XL	(axis->assigned_format, FALSE));
+			g_value_set_string (value,
+				go_format_as_XL	(axis->assigned_format));
 		else
 			g_value_set_static_string (value, NULL);
 		break;
@@ -1448,55 +1465,59 @@ typedef struct {
 	GogDataset *set;
 	unsigned dim;
 	gulong update_editor_handler;
-	gulong changed_handler;
+	gulong toggle_handler;
 } ElemToggleData;
 
 static void
 elem_toggle_data_free (ElemToggleData *data)
 {
 	g_signal_handler_disconnect (G_OBJECT (data->set), data->update_editor_handler);
-	g_signal_handler_disconnect (G_OBJECT (data->set), data->changed_handler);
 	g_free (data);
 }
 
 static void
-cb_enable_dim (GtkToggleButton *toggle_button, ElemToggleData *closure)
+set_to_auto_value (ElemToggleData *closure)
 {
-	gboolean is_auto = gtk_toggle_button_get_active (toggle_button);
 	double bound = GOG_AXIS (closure->set)->auto_bound [closure->dim];
 
-	gtk_widget_set_sensitive (closure->editor, !is_auto);
-
-	if (is_auto) /* clear the data */
-		gog_dataset_set_dim (closure->set, closure->dim, NULL, NULL);
-
 	if (go_finite (bound) && DBL_MAX > bound && bound > -DBL_MAX) {
 		char *str = g_strdup_printf ("%g", bound);
 		g_object_set (closure->editor, "text", str, NULL);
 		g_free (str);
 	} else
 		g_object_set (closure->editor, "text", "", NULL);
+
 }
 
 static void
-cb_axis_bound_changed (GogObject *axis, gboolean resize, ElemToggleData *closure)
+cb_enable_dim (GtkToggleButton *toggle_button, ElemToggleData *closure)
 {
-	if (gtk_toggle_button_get_active (closure->toggle)) {
-		double bound = GOG_AXIS (closure->set)->auto_bound [closure->dim];
-		if (go_finite (bound) && DBL_MAX > bound && bound > -DBL_MAX) {
-			char *str = g_strdup_printf ("%g", bound);
-			g_object_set (closure->editor, "text", str, NULL);
-			g_free (str);
-		} else
-			g_object_set (closure->editor, "text", "", NULL);
-	}
+	gboolean is_auto = gtk_toggle_button_get_active (toggle_button);
+
+	gtk_widget_set_sensitive (closure->editor, !is_auto);
+
+	if (is_auto)
+		gog_dataset_set_dim (closure->set, closure->dim, NULL, NULL);
+
+	set_to_auto_value (closure);
 }
 
 static void
 cb_update_dim_editor (GogObject *gobj, ElemToggleData *closure)
 {
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (closure->toggle),
-		gog_dataset_get_dim (closure->set, closure->dim) == NULL);
+	gboolean is_auto;
+
+	g_signal_handler_block (closure->toggle, closure->toggle_handler);
+
+	is_auto = (gog_dataset_get_dim (closure->set, closure->dim) == NULL);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (closure->toggle), is_auto);
+	gtk_widget_set_sensitive (GTK_WIDGET (closure->editor), !is_auto);
+
+	if (is_auto)
+		set_to_auto_value (closure);
+
+	g_signal_handler_unblock (closure->toggle, closure->toggle_handler);
 }
 
 static void
@@ -1514,26 +1535,25 @@ make_dim_editor (GogDataset *set, GtkTable *table, unsigned dim,
 	info->set = set;
 	info->dim = dim;
 	info->toggle = GTK_TOGGLE_BUTTON (toggle);
-	
-	g_signal_connect (G_OBJECT (toggle),
-			  "toggled",
-			  G_CALLBACK (cb_enable_dim), info);
+
+	info->toggle_handler = g_signal_connect (G_OBJECT (toggle),
+						 "toggled",
+						 G_CALLBACK (cb_enable_dim), info);
+
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle),
 				      gog_dataset_get_dim (set, dim) == NULL);
 
-	info->update_editor_handler = g_signal_connect (G_OBJECT (set), 
-							"update-editor", 
+	info->update_editor_handler = g_signal_connect (G_OBJECT (set),
+							"update-editor",
 							G_CALLBACK (cb_update_dim_editor), info);
-	info->changed_handler = g_signal_connect (G_OBJECT (set),
-						  "changed",
-						  G_CALLBACK (cb_axis_bound_changed), info);
+
 	g_object_weak_ref (G_OBJECT (toggle), (GWeakNotify) elem_toggle_data_free, info);
 
 	gtk_table_attach (table, toggle,
 		0, 1, dim + 1, dim + 2, GTK_FILL, 0, 0, 0);
 	gtk_table_attach (table, editor,
 		1, 2, dim + 1, dim + 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
-	
+
 }
 
 static void
@@ -1574,7 +1594,7 @@ cb_polar_unit_changed (GtkComboBox *combo,
 	GOFormat *format;
 
 	axis->polar_unit = gtk_combo_box_get_active (combo);
-	format = go_format_new_from_XL (polar_units[axis->polar_unit].xl_format, FALSE);
+	format = go_format_new_from_XL (polar_units[axis->polar_unit].xl_format);
 
 	if (gog_axis_set_format (axis, format) &&
 	    state->format_selector != NULL) 
@@ -1687,28 +1707,29 @@ gog_axis_populate_editor (GogObject *gobj,
 			     glade_xml_get_widget (gui, "axis_pref_box"),
 			     _("Scale"));
 
-	/* Style page */
-	(GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
+	if (gog_axis_get_atype (axis) < GOG_AXIS_VIRTUAL) {
+	    /* Style page */
+	    (GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
-	/* Format page */
-	if (!axis->is_discrete && gog_axis_get_atype (axis) != GOG_AXIS_PSEUDO_3D) {
-		w = go_format_sel_new_full (TRUE);
-		state->format_selector = w;
+	    /* Format page */
+	    if (!axis->is_discrete) {
+		    w = go_format_sel_new_full (TRUE);
+		    state->format_selector = w;
 
-		if (axis->assigned_format != NULL && !go_format_is_general (axis->assigned_format))
-			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
-				axis->assigned_format);
-		else if (axis->format != NULL)
-			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
-				axis->format);
+		    if (axis->assigned_format != NULL && !go_format_is_general (axis->assigned_format))
+			    go_format_sel_set_style_format (GO_FORMAT_SEL (w),
+				    axis->assigned_format);
+		    else if (axis->format != NULL)
+			    go_format_sel_set_style_format (GO_FORMAT_SEL (w),
+				    axis->format);
 
-		gog_editor_add_page (editor, w, _("Format"));
+		    gog_editor_add_page (editor, w, _("Format"));
 
-		gtk_widget_show (w);
-		g_signal_connect (G_OBJECT (w),
-			"format_changed", G_CALLBACK (cb_axis_fmt_changed), axis);
+		    gtk_widget_show (w);
+		    g_signal_connect (G_OBJECT (w),
+			    "format_changed", G_CALLBACK (cb_axis_fmt_changed), axis);
+	    }
 	}
-
 	w = glade_xml_get_widget (gui, "axis_pref_box");
 	g_object_set_data_full (G_OBJECT (w), "state", state,
 				(GDestroyNotify)gog_axis_pref_state_free);
@@ -1757,32 +1778,40 @@ gog_axis_class_init (GObjectClass *gobject_klass)
 
 	/* no need to persist, the role handles that */
 	g_object_class_install_property (gobject_klass, AXIS_PROP_TYPE,
-		g_param_spec_int ("type", "Type",
-			"GogAxisType",
-			GOG_AXIS_UNKNOWN, GOG_AXIS_TYPES, GOG_AXIS_UNKNOWN, G_PARAM_READWRITE));
+		g_param_spec_int ("type", _("Type"),
+			_("Numerical type of this axis"),
+			GOG_AXIS_UNKNOWN, GOG_AXIS_TYPES, GOG_AXIS_UNKNOWN, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_INVERT,
-		g_param_spec_boolean ("invert-axis", NULL,
-			"Scale from high to low rather than low to high",
-			FALSE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("invert-axis", _("Invert axis"),
+			_("Scale from high to low rather than low to high"),
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_MAP,
-		g_param_spec_string ("map-name", "MapName",
-			"The name of the map for scaling",
-			"linear", G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("map-name", _("MapName"),
+			_("The name of the map for scaling"),
+			"linear", 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_ASSIGNED_FORMAT_STR_XL,
-		g_param_spec_string ("assigned-format-string-XL", NULL,
-			"The user assigned format to use for non-discrete axis labels (XL format)",
-			"General", G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("assigned-format-string-XL", 
+			_("Assigned XL format"),
+			_("The user assigned format to use for non-discrete axis labels (XL format)"),
+			"General", 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_CIRCULAR_ROTATION,
-		g_param_spec_double ("circular-rotation", "Rotation of circular axis", 
-				     "Rotation of circular axis",
-				     GOG_AXIS_CIRCULAR_ROTATION_MIN, 
-				     GOG_AXIS_CIRCULAR_ROTATION_MAX,
-				     0.0, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_double ("circular-rotation", 
+			_("Rotation of circular axis"), 
+			_("Rotation of circular axis"),
+			GOG_AXIS_CIRCULAR_ROTATION_MIN, 
+			GOG_AXIS_CIRCULAR_ROTATION_MAX,
+			0.0, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_POLAR_UNIT,
-		g_param_spec_string ("polar-unit", "Polar axis set unit", 
-				     "Polar axis set unit", 
-				     polar_units[GOG_AXIS_POLAR_UNIT_DEGREES].name,
-				     G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("polar-unit", 
+			_("Polar axis set unit"), 
+			_("Polar axis set unit"), 
+			polar_units[GOG_AXIS_POLAR_UNIT_DEGREES].name,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
@@ -1885,7 +1914,7 @@ gog_axis_is_center_on_ticks (GogAxis const *axis)
  * @axis : #GogAxis
  * 
  * Returns: TRUE if @axis enumerates a set of discrete items, rather than a
- * continuous value
+ * 	continuous value
  **/ 
 gboolean
 gog_axis_is_discrete (GogAxis const *axis)
@@ -2143,8 +2172,8 @@ gog_axis_set_polar_unit (GogAxis *axis, GogAxisPolarUnit unit)
  * gog_axis_get_polar_unit:
  * @axis: a #GogAxis
  *
- * returns: unit of @axis if it's a circular axis of a polar
- * axis set, -1 otherwise.
+ * Returns: unit of @axis if it's a circular axis of a polar
+ * 	axis set, -1 otherwise.
  **/
 
 GogAxisPolarUnit
@@ -2159,13 +2188,11 @@ gog_axis_get_polar_unit (GogAxis *axis)
  * gog_axis_get_circular_perimeter:
  * @axis: a #GogAxis
  *
- * returns: perimeter of a circular #GogAxis of a polar axis set.
- * 
+ * Returns: perimeter of a circular #GogAxis of a polar axis set.
  * 	radians: 2*pi
  * 	degrees: 360.0
  * 	grads  : 400.0
  **/
-
 double
 gog_axis_get_polar_perimeter (GogAxis *axis)
 {
@@ -2178,9 +2205,8 @@ gog_axis_get_polar_perimeter (GogAxis *axis)
  * gog_axis_get_circular_rotation:
  * @axis: a #GogAxis
  *
- * returns: rotation of a circular #GogAxis.
+ * Returns: rotation of a circular #GogAxis.
  **/
-
 double
 gog_axis_get_circular_rotation (GogAxis *axis)
 {
@@ -2292,7 +2318,7 @@ gog_axis_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 		if (IS_GOG_LABEL (child->model) && (pos & GOG_POSITION_MANUAL)) {
 			gog_view_size_request (child, &available, &req);
 			child_bbox = gog_object_get_manual_allocation (gog_view_get_model (child), 
-								       plot_area, &req);
+								       bbox, &req);
 			gog_view_size_allocate (child, &child_bbox);
 		} else {
 			if (GOG_POSITION_IS_SPECIAL (pos)) {
