@@ -24,14 +24,14 @@
 #include "gog-1.5d.h"
 #include <goffice/graph/gog-series-lines.h>
 #include <goffice/graph/gog-view.h>
-#include <goffice/graph/gog-chart.h>
+#include <goffice/graph/gog-chart-map.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/data/go-data.h>
+#include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-marker.h>
-#include <goffice/utils/go-math.h>
 
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
@@ -285,9 +285,11 @@ gog_line_plot_class_init (GogPlot1_5dClass *gog_plot_1_5d_klass)
 	gobject_klass->get_property = gog_line_get_property;
 
 	g_object_class_install_property (gobject_klass, GOG_LINE_PROP_DEFAULT_STYLE_HAS_MARKERS,
-		g_param_spec_boolean ("default-style-has-markers", NULL,
-			"Should the default style of a series include markers",
-			TRUE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("default-style-has-markers", 
+			_("Default markers"),
+			_("Should the default style of a series include markers"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	gog_klass->type_name	= gog_line_plot_type_name;
 	gog_klass->view_type	= gog_line_view_get_type ();
@@ -426,8 +428,10 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next) {
 		series = ptr->data;
 
-		if (!gog_series_is_valid (GOG_SERIES (series)))
+		if (!gog_series_is_valid (GOG_SERIES (series))) {
+			vals[i] = NULL;
 			continue;
+		}
 
 		vals[i] = go_data_vector_get_values (
 			GO_DATA_VECTOR (series->base.values[1].data));
@@ -469,7 +473,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 		sum = abs_sum = 0.0;
 		if (type == GOG_1_5D_AS_PERCENTAGE) {
 			for (i = 0; i < num_series; i++)
-				if (gog_axis_map_finite (y_map, vals[i][j-1]))
+				if (vals[i] && gog_axis_map_finite (y_map, vals[i][j-1]))
 					abs_sum += fabs (vals[i][j-1]);
 			is_null = (go_sub_epsilon (abs_sum) <= 0.);
 		} else
@@ -567,9 +571,9 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 
 		}
 	}
-	
-	gog_renderer_push_clip (view->renderer, 
-				gog_renderer_get_rectangle_vpath (&view->allocation));
+
+	gog_renderer_push_clip_rectangle (view->renderer, view->allocation.x, view->allocation.y,
+					  view->allocation.w, view->allocation.h);
 
 	for (i = 0; i < num_series; i++) {
 
